<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>AudioContainerControl</name>
    <message>
        <source>RAW (headerless) file format</source>
        <translation>Format de fitxer RAW (sense capçalera)</translation>
    </message>
    <message>
        <source>WAV file format</source>
        <translation>Format de fitxer WAV</translation>
    </message>
</context>
<context>
    <name>AudioEncoderControl</name>
    <message>
        <source>Linear PCM audio data</source>
        <translation>Dades d&apos;àudio PCM lineal</translation>
    </message>
</context>
<context>
    <name>BbCameraAudioEncoderSettingsControl</name>
    <message>
        <source>No compression</source>
        <translation type="vanished">Sense compressió</translation>
    </message>
    <message>
        <source>AAC compression</source>
        <translation type="vanished">Compressió AAC</translation>
    </message>
    <message>
        <source>PCM uncompressed</source>
        <translation type="vanished">PCM sense comprimir</translation>
    </message>
</context>
<context>
    <name>BbCameraMediaRecorderControl</name>
    <message>
        <source>Unable to retrieve mute status</source>
        <translation type="vanished">No s&apos;ha pogut recuperar l&apos;estat de silenci</translation>
    </message>
    <message>
        <source>Unable to retrieve audio input volume</source>
        <translation type="vanished">No s&apos;ha pogut recuperar el volum de l&apos;entrada d&apos;àudio</translation>
    </message>
    <message>
        <source>Unable to set mute status</source>
        <translation type="vanished">No s&apos;ha pogut establir l&apos;estat de silenci</translation>
    </message>
    <message>
        <source>Unable to set audio input volume</source>
        <translation type="vanished">No s&apos;ha pogut establir el volum de l&apos;entrada d&apos;àudio</translation>
    </message>
</context>
<context>
    <name>BbCameraSession</name>
    <message>
        <source>Camera provides image in unsupported format</source>
        <translation type="vanished">La càmera proporciona una imatge en un format no acceptat</translation>
    </message>
    <message>
        <source>Could not load JPEG data from frame</source>
        <translation type="vanished">No s&apos;han pogut carregar les dades JPEG des del fotograma</translation>
    </message>
    <message>
        <source>Camera not ready</source>
        <translation type="vanished">La càmera no està preparada</translation>
    </message>
    <message>
        <source>Unable to apply video settings</source>
        <translation type="vanished">No s&apos;han pogut aplicar els ajustaments al vídeo</translation>
    </message>
    <message>
        <source>Could not open destination file:
%1</source>
        <translation type="vanished">No s&apos;ha pogut obrir el fitxer de destinació:
%1</translation>
    </message>
    <message>
        <source>Unable to open camera</source>
        <translation type="vanished">No s&apos;ha pogut obrir la càmera</translation>
    </message>
    <message>
        <source>Unable to retrieve native camera orientation</source>
        <translation type="vanished">No s&apos;ha pogut recuperar l&apos;orientació nativa de la càmera</translation>
    </message>
    <message>
        <source>Unable to close camera</source>
        <translation type="vanished">No s&apos;ha pogut tancar la càmera</translation>
    </message>
    <message>
        <source>Unable to start video recording</source>
        <translation type="vanished">No s&apos;ha pogut iniciar la gravació de vídeo</translation>
    </message>
    <message>
        <source>Unable to stop video recording</source>
        <translation type="vanished">No s&apos;ha pogut aturar la gravació de vídeo</translation>
    </message>
</context>
<context>
    <name>BbCameraVideoEncoderSettingsControl</name>
    <message>
        <source>No compression</source>
        <translation type="vanished">Sense compressió</translation>
    </message>
    <message>
        <source>AVC1 compression</source>
        <translation type="vanished">Compressió AVC1</translation>
    </message>
    <message>
        <source>H264 compression</source>
        <translation type="vanished">Compressió H264</translation>
    </message>
</context>
<context>
    <name>BbImageEncoderControl</name>
    <message>
        <source>JPEG image</source>
        <translation type="vanished">Imatge JPEG</translation>
    </message>
</context>
<context>
    <name>BbVideoDeviceSelectorControl</name>
    <message>
        <source>Front Camera</source>
        <translation type="vanished">Càmera frontal</translation>
    </message>
    <message>
        <source>Rear Camera</source>
        <translation type="vanished">Càmera posterior</translation>
    </message>
    <message>
        <source>Desktop Camera</source>
        <translation type="vanished">Càmera de l&apos;escriptori</translation>
    </message>
</context>
<context>
    <name>CameraBinImageCapture</name>
    <message>
        <source>Camera not ready</source>
        <translation>La càmera no està preparada</translation>
    </message>
</context>
<context>
    <name>CameraBinImageEncoder</name>
    <message>
        <source>JPEG image</source>
        <translation>Imatge JPEG</translation>
    </message>
</context>
<context>
    <name>CameraBinRecorder</name>
    <message>
        <source>QMediaRecorder::pause() is not supported by camerabin2.</source>
        <translation>QMediaRecorder::pause() no és admès pel «camerabin2».</translation>
    </message>
    <message>
        <source>Service has not been started</source>
        <translation>El servei no s&apos;ha iniciat</translation>
    </message>
    <message>
        <source>Recording permissions are not available</source>
        <translation>Els permisos d&apos;enregistrament no estan disponibles</translation>
    </message>
</context>
<context>
    <name>CameraBinSession</name>
    <message>
        <source>Camera error</source>
        <translation>Error de la càmera</translation>
    </message>
</context>
<context>
    <name>DSCameraSession</name>
    <message>
        <source>Failed to configure preview format</source>
        <translation>Ha fallat en configurar el format de la vista prèvia</translation>
    </message>
    <message>
        <source>Failed to connect graph</source>
        <translation>Ha fallat en connectar amb el gràfic</translation>
    </message>
    <message>
        <source>Failed to get stream control</source>
        <translation>Ha fallat en obtenir el control del flux</translation>
    </message>
    <message>
        <source>Failed to start</source>
        <translation>Ha fallat en iniciar</translation>
    </message>
    <message>
        <source>Failed to stop</source>
        <translation>Ha fallat en aturar</translation>
    </message>
    <message>
        <source>Camera not ready for capture</source>
        <translation>La càmera no està llesta per a la captura</translation>
    </message>
    <message>
        <source>Could not save image to file.</source>
        <translation>No s&apos;ha pogut desar la imatge al fitxer.</translation>
    </message>
    <message>
        <source>Failed to create filter graph</source>
        <translation>Ha fallat en crear el gràfic de filtres</translation>
    </message>
    <message>
        <source>Failed to create graph builder</source>
        <translation>Ha fallat en crear el constructor de gràfics</translation>
    </message>
    <message>
        <source>Failed to connect capture graph and filter graph</source>
        <translation>Ha fallat en crear el gràfic de captures i el gràfic de filtres</translation>
    </message>
    <message>
        <source>No capture device found</source>
        <translation>No s&apos;ha trobat cap dispositiu de captura</translation>
    </message>
    <message>
        <source>Failed to create null renderer</source>
        <translation>Ha fallat en crear el renderitzador nul</translation>
    </message>
</context>
<context>
    <name>MFPlayerSession</name>
    <message>
        <source>Invalid stream source.</source>
        <translation>Origen no vàlid del flux.</translation>
    </message>
    <message>
        <source>Attempting to play invalid Qt resource.</source>
        <translation>S&apos;intenta reproduir un recurs no vàlid de les Qt.</translation>
    </message>
    <message>
        <source>The system cannot find the file specified.</source>
        <translation>El sistema no pot trobar el fitxer especificat.</translation>
    </message>
    <message>
        <source>The specified server could not be found.</source>
        <translation>No s&apos;ha pogut trobar el servidor especificat.</translation>
    </message>
    <message>
        <source>Unsupported media type.</source>
        <translation>Tipus de suport no acceptat.</translation>
    </message>
    <message>
        <source>Failed to load source.</source>
        <translation>Ha fallat en carregar l&apos;origen.</translation>
    </message>
    <message>
        <source>Cannot create presentation descriptor.</source>
        <translation>No s&apos;ha pogut crear el descriptor de la presentació.</translation>
    </message>
    <message>
        <source>Failed to get stream count.</source>
        <translation>Ha fallat en obtenir el compte del flux.</translation>
    </message>
    <message>
        <source>Failed to create topology.</source>
        <translation>Ha fallat en crear la topologia.</translation>
    </message>
    <message>
        <source>Unable to play any stream.</source>
        <translation>No es pot reproduir cap flux.</translation>
    </message>
    <message>
        <source>Unable to play.</source>
        <translation>No es pot reproduir.</translation>
    </message>
    <message>
        <source>Failed to set topology.</source>
        <translation>Ha fallat en establir la topologia.</translation>
    </message>
    <message>
        <source>Unknown stream type.</source>
        <translation>Tipus de flux desconegut.</translation>
    </message>
    <message>
        <source>Failed to stop.</source>
        <translation>Ha fallat en aturar.</translation>
    </message>
    <message>
        <source>failed to start playback</source>
        <translation>Ha fallat en iniciar la reproducció</translation>
    </message>
    <message>
        <source>Failed to pause.</source>
        <translation>Ha fallat en fer una pausa.</translation>
    </message>
    <message>
        <source>Unable to create mediasession.</source>
        <translation>No es pot crear una sessió de suports.</translation>
    </message>
    <message>
        <source>Unable to pull session events.</source>
        <translation>No es poden prémer esdeveniments de sessió.</translation>
    </message>
    <message>
        <source>Failed to seek.</source>
        <translation>Ha fallat en cercar.</translation>
    </message>
    <message>
        <source>Media session non-fatal error.</source>
        <translation>Error no fatal en la sessió del suport.</translation>
    </message>
    <message>
        <source>Media session serious error.</source>
        <translation>Error greu en la sessió del suport.</translation>
    </message>
    <message>
        <source>Unsupported media, a codec is missing.</source>
        <translation>Suport no acceptat, manca un còdec.</translation>
    </message>
</context>
<context>
    <name>PLSParser</name>
    <message>
        <source>Error parsing playlist: %1, expected count = %2</source>
        <translation type="vanished">Error en analitzar la llista de reproducció: %1, s&apos;esperava el compte = %2</translation>
    </message>
    <message>
        <source>Error parsing playlist at line[%1], expected version = 2</source>
        <translation type="vanished">Error en analitzar la llista de reproducció a la línia [%1], s&apos;esperava la versió = 2</translation>
    </message>
    <message>
        <source>Error parsing playlist at line[%1]:%2</source>
        <translation type="vanished">Error en analitzar la llista de reproducció a la línia [%1]: %2</translation>
    </message>
</context>
<context>
    <name>QAndroidAudioEncoderSettingsControl</name>
    <message>
        <source>Adaptive Multi-Rate Narrowband (AMR-NB) audio codec</source>
        <translation>Còdec d&apos;àudio «Adaptive Multi-Rate Narrowband» (AMR-NB)</translation>
    </message>
    <message>
        <source>Adaptive Multi-Rate Wideband (AMR-WB) audio codec</source>
        <translation>Còdec d&apos;àudio «Adaptive Multi-Rate Wideband» (AMR-WB)</translation>
    </message>
    <message>
        <source>AAC Low Complexity (AAC-LC) audio codec</source>
        <translation>Còdec d&apos;àudio AAC de baixa complexitat (AAC-LC)</translation>
    </message>
</context>
<context>
    <name>QAndroidCameraSession</name>
    <message>
        <source>Camera cannot be started without a viewfinder.</source>
        <translation type="vanished">La càmera no es pot iniciar sense un visor.</translation>
    </message>
    <message>
        <source>Camera not ready</source>
        <translation>La càmera no està llesta</translation>
    </message>
    <message>
        <source>Drive mode not supported</source>
        <extracomment>Drive mode is the camera&apos;s shutter mode, for example single shot, continuos exposure, etc.</extracomment>
        <translation>El mode continu no s&apos;accepta</translation>
    </message>
    <message>
        <source>Failed to capture image</source>
        <translation>Ha fallat en capturar la imatge</translation>
    </message>
    <message>
        <source>Camera preview failed to start.</source>
        <translation>La vista prèvia de la càmera ha fallat en iniciar-se.</translation>
    </message>
    <message>
        <source>Could not open destination file: %1</source>
        <translation>No s&apos;ha pogut obrir el fitxer de destinació: %1</translation>
    </message>
</context>
<context>
    <name>QAndroidImageEncoderControl</name>
    <message>
        <source>JPEG image</source>
        <translation>Imatge JPEG</translation>
    </message>
</context>
<context>
    <name>QAndroidMediaContainerControl</name>
    <message>
        <source>MPEG4 media file format</source>
        <translation>Format de fitxer per a suports MPEG4</translation>
    </message>
    <message>
        <source>3GPP media file format</source>
        <translation>Format de fitxer per a suports 3GPP</translation>
    </message>
    <message>
        <source>AMR NB file format</source>
        <translation>Format de fitxer AMR NB</translation>
    </message>
    <message>
        <source>AMR WB file format</source>
        <translation>Format de fitxer AMR WB</translation>
    </message>
</context>
<context>
    <name>QAndroidVideoEncoderSettingsControl</name>
    <message>
        <source>H.263 compression</source>
        <translation>Compressió H.263</translation>
    </message>
    <message>
        <source>H.264 compression</source>
        <translation>Compressió H.264</translation>
    </message>
    <message>
        <source>MPEG-4 SP compression</source>
        <translation>Compressió SP per a MPEG-4</translation>
    </message>
</context>
<context>
    <name>QAudioDecoder</name>
    <message>
        <source>The QAudioDecoder object does not have a valid service</source>
        <translation>L&apos;objecte «QAudioDecoder» no té un servei vàlid</translation>
    </message>
</context>
<context>
    <name>QCamera</name>
    <message>
        <source>The camera service is missing</source>
        <translation>Manca el servei de la càmera</translation>
    </message>
</context>
<context>
    <name>QCameraImageCapture</name>
    <message>
        <source>Device does not support images capture.</source>
        <translation>El dispositiu no admet la captura d&apos;imatges.</translation>
    </message>
</context>
<context>
    <name>QDeclarativeAudio</name>
    <message>
        <source>volume should be between 0.0 and 1.0</source>
        <translation>el volum hauria d&apos;estar entre 0,0 i 1,0</translation>
    </message>
</context>
<context>
    <name>QGstreamerAudioDecoderSession</name>
    <message>
        <source>Cannot play stream of type: &lt;unknown&gt;</source>
        <translation>No s&apos;ha pogut reproduir un flux del tipus: &lt;desconegut&gt;</translation>
    </message>
</context>
<context>
    <name>QGstreamerAudioEncode</name>
    <message>
        <source>Raw PCM audio</source>
        <translation type="vanished">Àudio PCM en RAW</translation>
    </message>
</context>
<context>
    <name>QGstreamerAudioInputSelector</name>
    <message>
        <source>System default device</source>
        <translation>Dispositiu predeterminat del sistema</translation>
    </message>
</context>
<context>
    <name>QGstreamerCameraControl</name>
    <message>
        <source>State not supported.</source>
        <translation>L&apos;estat no està implementat.</translation>
    </message>
</context>
<context>
    <name>QGstreamerCaptureSession</name>
    <message>
        <source>Could not create an audio source element</source>
        <translation>No s&apos;ha pogut crear un element per a l&apos;origen de l&apos;àudio</translation>
    </message>
    <message>
        <source>Failed to build media capture pipeline.</source>
        <translation>Ha fallat en construir el tub per a la captura del suport.</translation>
    </message>
</context>
<context>
    <name>QGstreamerImageCaptureControl</name>
    <message>
        <source>Not ready to capture</source>
        <translation>No està llest per a capturar</translation>
    </message>
</context>
<context>
    <name>QGstreamerImageEncode</name>
    <message>
        <source>JPEG image encoder</source>
        <translation>Codificador per a imatges JPEG</translation>
    </message>
</context>
<context>
    <name>QGstreamerPlayerControl</name>
    <message>
        <source>Attempting to play invalid Qt resource</source>
        <translation type="vanished">S&apos;intenta reproduir un recurs no vàlid de les Qt</translation>
    </message>
    <message>
        <source>Attempting to play invalid user stream</source>
        <translation>S&apos;intenta reproduir un flux d&apos;usuari no vàlid</translation>
    </message>
</context>
<context>
    <name>QGstreamerPlayerSession</name>
    <message>
        <source>Cannot play stream of type: &lt;unknown&gt;</source>
        <translation>No s&apos;ha pogut reproduir un flux del tipus: &lt;desconegut&gt;</translation>
    </message>
    <message>
        <source>UDP source timeout</source>
        <translation>Temps d&apos;espera per a l&apos;origen UDP</translation>
    </message>
    <message>
        <source>Media is loaded as a playlist</source>
        <translation type="vanished">El suport s&apos;ha carregat com a una llista de reproducció</translation>
    </message>
</context>
<context>
    <name>QGstreamerRecorderControl</name>
    <message>
        <source>Service has not been started</source>
        <translation>El servei no s&apos;ha iniciat</translation>
    </message>
    <message>
        <source>Not compatible codecs and container format.</source>
        <translation>Els còdecs i el format contenidor no són compatibles.</translation>
    </message>
</context>
<context>
    <name>QGstreamerVideoInputDeviceControl</name>
    <message>
        <source>Main camera</source>
        <translation>Càmera principal</translation>
    </message>
    <message>
        <source>Front camera</source>
        <translation>Càmera frontal</translation>
    </message>
</context>
<context>
    <name>QMediaPlayer</name>
    <message>
        <source>Attempting to play invalid Qt resource</source>
        <translation>S&apos;intenta reproduir un recurs no vàlid de les Qt</translation>
    </message>
    <message>
        <source>The QMediaPlayer object does not have a valid service</source>
        <translation>L&apos;objecte «QMediaPlayer» no té un servei vàlid</translation>
    </message>
</context>
<context>
    <name>QMediaPlaylist</name>
    <message>
        <source>Could not add items to read only playlist.</source>
        <translation>No es poden afegir elements a una llista de reproducció de només lectura.</translation>
    </message>
    <message>
        <source>Playlist format is not supported</source>
        <translation>No s&apos;admet el format de la llista de reproducció</translation>
    </message>
    <message>
        <source>The file could not be accessed.</source>
        <translation>No s&apos;ha pogut accedir al fitxer.</translation>
    </message>
    <message>
        <source>Playlist format is not supported.</source>
        <translation>No s&apos;admet el format de la llista de reproducció.</translation>
    </message>
</context>
<context>
    <name>QMultimediaDeclarativeModule</name>
    <message>
        <source>CameraCapture is provided by Camera</source>
        <translation>La captura és proporcionada per la càmera</translation>
    </message>
    <message>
        <source>CameraRecorder is provided by Camera</source>
        <translation>La gravació és proporcionada per la càmera</translation>
    </message>
    <message>
        <source>CameraExposure is provided by Camera</source>
        <translation>L&apos;exposició és proporcionada per la càmera</translation>
    </message>
    <message>
        <source>CameraFocus is provided by Camera</source>
        <translation>L&apos;enfocament és proporcionat per la càmera</translation>
    </message>
    <message>
        <source>CameraFlash is provided by Camera</source>
        <translation>El flaix és proporcionat per la càmera</translation>
    </message>
    <message>
        <source>CameraImageProcessing is provided by Camera</source>
        <translation>El processament de la imatge és proporcionat per la càmera</translation>
    </message>
    <message>
        <source>CameraViewfinder is provided by Camera</source>
        <translation>El visor és proporcionat per la càmera</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>%1 playlist type is unknown</source>
        <translation type="vanished">El tipus %1 per a llistes de reproducció és desconegut</translation>
    </message>
    <message>
        <source>invalid line in playlist file</source>
        <translation type="vanished">línia no vàlida al fitxer de la llista de reproducció</translation>
    </message>
    <message>
        <source>Empty file provided</source>
        <translation type="vanished">S&apos;ha proporcionat un fitxer buit</translation>
    </message>
</context>
<context>
    <name>QPlaylistFileParser</name>
    <message>
        <source>%1 playlist type is unknown</source>
        <translation>El tipus %1 per a llistes de reproducció és desconegut</translation>
    </message>
    <message>
        <source>invalid line in playlist file</source>
        <translation>línia no vàlida al fitxer de la llista de reproducció</translation>
    </message>
    <message>
        <source>Invalid stream</source>
        <translation>Flux no vàlid</translation>
    </message>
    <message>
        <source>Empty file provided</source>
        <translation>S&apos;ha proporcionat un fitxer buit</translation>
    </message>
    <message>
        <source>%1 does not exist</source>
        <translation>%1 no existeix</translation>
    </message>
</context>
<context>
    <name>QPlaylistFileParserPrivate</name>
    <message>
        <source>%1 playlist type is unknown</source>
        <translation type="vanished">El tipus %1 per a llistes de reproducció és desconegut</translation>
    </message>
    <message>
        <source>invalid line in playlist file</source>
        <translation type="vanished">línia no vàlida al fitxer de la llista de reproducció</translation>
    </message>
    <message>
        <source>Empty file provided</source>
        <translation type="vanished">S&apos;ha proporcionat un fitxer buit</translation>
    </message>
</context>
<context>
    <name>QWinRTCameraImageCaptureControl</name>
    <message>
        <source>Camera not ready</source>
        <translation>La càmera no està preparada</translation>
    </message>
    <message>
        <source>Invalid photo data length.</source>
        <translation>Longitud no vàlida en les dades de la fotografia.</translation>
    </message>
    <message>
        <source>Image saving failed</source>
        <translation>Ha fallat en desar la imatge</translation>
    </message>
</context>
<context>
    <name>QWinRTImageEncoderControl</name>
    <message>
        <source>JPEG image</source>
        <translation>Imatge JPEG</translation>
    </message>
</context>
</TS>
